==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/Frame.h <==
/* $Id: Frame.h,v 1.2 1997/04/07 15:33:19 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_FRAME_H_)
#define _XARM_FRAME_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Manager.h>

class FrameClass : public ManagerClass {
 protected:
   FrameClass() {} /* only a derived class can make this */
   virtual WidgetClass classPointer() { return xmFrameWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmFrame"; } 
 public:
   /* resources */
   void marginHeight(Dimension);
   Dimension marginHeight();
   void marginWidth(Dimension);
   Dimension marginWidth();
   void shadowType(unsigned char);
   unsigned char shadowType();
};

class Frame : public FrameClass {
 public:
   Frame(Widget w_parent,
         ArgList arglist = NULL,
         Cardinal cnt = 0,
         _XtString name = NULL);
   Frame(_XtString name, Widget w_parent);
   Frame(Widget w_parent, XarmArg &args, _XtString name);
};

#endif

==> Xarm-1.3.1.tar.gz: Xarm-1.3.1/include/Xarm/Frame.h <==
/* $Id: Frame.h,v 1.3 1999/01/15 10:07:02 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_FRAME_H_)
#define _XARM_FRAME_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Manager.h>

class FrameClass : public ManagerClass {
 protected:
   FrameClass() {} /* only a derived class can make this */
   virtual WidgetClass classPointer() { return xmFrameWidgetClass; }
   virtual _XtString className() { return (_XtString) "XmFrame"; } 
 public:
   /* resources */
   void marginHeight(Dimension);
   Dimension marginHeight() const;
   void marginWidth(Dimension);
   Dimension marginWidth() const;
   void shadowType(unsigned char);
   unsigned char shadowType() const;
};

class Frame : public FrameClass {
 public:
   Frame(Widget w_parent,
         ArgList arglist = NULL,
         Cardinal cnt = 0,
         _XtString name = NULL);
   Frame(_XtString name, Widget w_parent);
   Frame(Widget w_parent, XarmArg &args, _XtString name);
};

#endif
